@@ -1,20 +1,20 @@
 import functools
-from typing import Literal
+from typing import Literal, cast
 from reactivex import Observable, compose, operators
 
 from ..models import CryptodotcomResponseMessage
 from .subscribe import subscribe_to_channel
-from .channels import ChannelName
 from ccxt import cryptocom
+from elm_framework_helpers.ccxt.models.orderbook import Orderbook, OrderbookEntry
 
 exchange = cryptocom()
 
 TickerData = dict[str, str]
 
 
-def to_order_book_data(symbol: str, message: CryptodotcomResponseMessage):
+def to_order_book_data(symbol: str, message: CryptodotcomResponseMessage) -> Orderbook:
     """Order book ccxt style https://docs.ccxt.com/en/latest/manual.html#order-book-structure"""
-    return exchange.parse_order_book(message.result["data"][0], symbol)
+    return cast(Orderbook, exchange.parse_order_book(message.result["data"][0], symbol))
 
 
 def subscribe_order_book(
