@@ -5,13 +5,6 @@ from reactivex import compose, operators, Observable
 from ..models.enhanced_websocket import EnhancedWebsocket
 from .bundle import WebsocketBundle, WebsocketMessageBundle, WebsocketStatusBundle
 from .message_types import WEBSOCKET_STATUS
-from .status import (
-    WEBSOCKET_OPENED,
-    WEBSOCKET_AUTHENTICATED,
-    Status,
-    WEBSOCKET_SYSTEM_ONLINE,
-    WEBSOCKET_CLOSED,
-)
 
 
 ReadyMessage = Tuple[EnhancedWebsocket, bool]
