@@ -46,7 +46,8 @@ def raw_websocket_connection(
 
             def on_close(_ws: WebSocketApp, close_status_code: int, close_msg: str):
                 logger.warning(
-                    "[SOCKET][RAW] Websocket closed | status: %s, close message: %s",
+                    "[SOCKET][RAW] Websocket closed | url: %s, status: %s, close message: %s",
+                    url,
                     close_status_code,
                     close_msg,
                 )
@@ -54,7 +55,7 @@ def raw_websocket_connection(
                 observer.on_error(Exception("Socket closed"))
 
             def on_open(_ws: WebSocketApp):
-                logger.info("[SOCKET][RAW] Websocket opened")
+                logger.info("[SOCKET][RAW] Websocket opened at %s", url)
                 observer.on_next((enhanced, WEBSOCKET_STATUS, WEBSOCKET_OPENED))
 
             def on_message(ws: WebSocketApp, message: bytes | str):
