@@ -5,22 +5,25 @@ from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubj
 from .user_balance import UserBalance, PositionBalance
 from .trade import Trade
 from .book import RawOrderbook, RawOrderbookEntry, OrderbookEntryNamedTuple, OrderbookDict
+from .framework import BookConfig, CryptodotcomContext
 
 __all__ = [
+    "BookConfig",
+    "CryptodotcomContext",
+    "CryptodotcomRequestMessage",
+    "CryptodotcomResponseMessage",
+    "EnhancedWebsocket",
+    "EnhancedWebsocketBehaviorSubject",
     "Order",
+    "OrderbookDict",
+    "OrderbookEntryNamedTuple",
+    "OrderDict",
     "OrderSide",
     "OrderStatus",
     "OrderType",
-    "OrderDict",
-    "CryptodotcomResponseMessage",
-    "CryptodotcomRequestMessage",
-    "EnhancedWebsocket",
-    "EnhancedWebsocketBehaviorSubject",
-    "UserBalance",
     "PositionBalance",
-    "Trade",
     "RawOrderbook",
     "RawOrderbookEntry",
-    "OrderbookEntryNamedTuple",
-    "OrderbookDict",
+    "Trade",
+    "UserBalance",
 ]
