@@ -106,7 +106,7 @@ class OrderDict(TypedDict):
     client_oid: Optional[str]
     order_type: Optional[str]
     time_in_force: Optional[str]
-    side: Literal["buy", "sell"]
+    side: Literal["BUY", "SELL"]
     exec_inst: Optional[list[str]]
     quantity: Optional[str]
     limit_price: Optional[str]
@@ -125,16 +125,16 @@ class OrderDict(TypedDict):
     update_time: Optional[int]
 
 
-def _is_side_order(x: OrderDict | Order, side: Literal["sell", "buy"]):
+def _is_side_order(x: OrderDict | Order, side: Literal["SELL", "BUY"]):
     return (x.side if type(x) == Order else x["side"]) == side  # type: ignore
 
 
 def is_buy_order(x: OrderDict | Order):
-    return _is_side_order(x, "buy")
+    return _is_side_order(x, "BUY")
 
 
 def is_sell_order(x: OrderDict | Order):
-    return _is_side_order(x, "sell")
+    return _is_side_order(x, "SELL")
 
 
 __all__ = [
