@@ -1,12 +1,13 @@
 from logging import getLogger
 from typing import Any, Callable, Literal
+import requests
 
 from ccxt import cryptocom
 from elm_framework_helpers.output import info_operator
 from reactivex import Observable, disposable, empty, just, operators, throw
 from reactivex.scheduler import NewThreadScheduler
 
-from ..connection import wait_for_response
+from ..connection import wait_for_response, prepare_request, send_request
 from ..events import MethodName
 from ..models import (
     CryptodotcomRequestMessage,
@@ -24,8 +25,8 @@ def wait_for_no_orders(
     return messages.pipe(
         operators.filter(lambda x: bool(x)),
         operators.timeout(2.0),
-        operators.catch(lambda *_: just(False)),
-        operators.map(lambda _: True),
+        operators.catch(lambda _exc, source: just(False)),
+        operators.map(lambda _x: True),
     )
 
 
@@ -71,19 +72,22 @@ def cancel_all_factory(
                     return just(True)
                 return throw(Exception("Refused to cancel orders %s", x.result))
 
+            message_id, sender = ws.request_to_observable(
+                CryptodotcomRequestMessage(
+                    MethodName.CANCEL_ALL,
+                    params={
+                        "instrument_name": market_id,
+                        "type": uppercase_type,
+                    },
+                )
+            )
+
             return disposable.CompositeDisposable(
                 sub,
                 response_messages.pipe(
                     wait_for_response(
-                        ws.send_message(
-                            CryptodotcomRequestMessage(
-                                MethodName.CANCEL_ALL,
-                                params={
-                                    "instrument_name": market_id,
-                                    "type": uppercase_type,
-                                },
-                            )
-                        ),
+                        message_id,
+                        sender,
                         2.0,
                     ),
                     operators.flat_map(check_should_wait),
@@ -93,3 +97,19 @@ def cancel_all_factory(
         return Observable(subscribe)
 
     return cancel_all
+
+
+def cancel_all_http_factory(
+    add_token: Callable[[requests.models.Request], requests.models.Request]
+):
+    def cancel_all_http(
+        pair: str, order_type: Literal["limit", "trigger", "all"]
+    ) -> Observable:
+        order_type = order_type.upper()  # type: ignore
+        message = CryptodotcomRequestMessage(
+            MethodName.CANCEL_ALL, {"instrument_name": pair, "type": order_type}
+        )
+        request = prepare_request(message)
+        return send_request(add_token(request))
+
+    return cancel_all_http
