@@ -4,7 +4,7 @@ from ..models import (
     CryptodotcomResponseMessage,
     EnhancedWebsocket,
     CryptodotcomRequestMessage,
-    EnhancedWebsocketBehaviorSubject
+    EnhancedWebsocketBehaviorSubject,
 )
 from elm_framework_helpers.output import info_operator
 from reactivex import Observable, operators, disposable, just, throw
@@ -27,16 +27,18 @@ def order_confirmation(
     return messages.pipe(
         operators.filter(is_match),
         operators.take(1),
-        operators.map(lambda x: (
-            exchange.parse_order(x.result["data"][0])
-        )),
-        operators.flat_map(lambda x: just(x) if x['status'] == 'open' else throw(x['status'])),
+        operators.map(lambda x: (exchange.parse_order(x.result["data"][0]))),
+        operators.flat_map(
+            lambda x: just(x) if x["status"] == "open" else throw(x["status"])
+        ),
         operators.timeout(2.0),
     )
 
 
 def create_order_factory(
-    messages: Observable[CryptodotcomResponseMessage], exchange: cryptocom, socket: EnhancedWebsocketBehaviorSubject
+    messages: Observable[CryptodotcomResponseMessage],
+    exchange: cryptocom,
+    socket: EnhancedWebsocketBehaviorSubject,
 ) -> Callable[
     [str, str, str, float, Optional[float], Optional[Any]], Observable[dict[str, Any]]
 ]:
@@ -57,19 +59,20 @@ def create_order_factory(
         price: Optional[float]=None,
         params=None,
     """
+
     def create_order(
         symbol: str,
         type: str,
         side: str,
         amount: float,
-        price: Optional[float]=None,
-        params: Optional[dict[str, Any]]=None,
+        price: Optional[float] = None,
+        params: Optional[dict[str, Any]] = None,
     ):
         """Create order
 
         Args:
-            symbol (str): 
-            type (str): 
+            symbol (str):
+            type (str):
             side (str): buy or sell
             amount (float): amount
             price (Optional[float], optional): price. Defaults to None.
@@ -87,8 +90,8 @@ def create_order_factory(
             "type": uppercaseType,
             "quantity": exchange.amount_to_precision(symbol, amount),
         }
-        if params.get('client_oid'):
-            request['client_oid'] = params['client_oid']
+        if params.get("client_oid"):
+            request["client_oid"] = params["client_oid"]
         if (uppercaseType == "LIMIT") or (uppercaseType == "STOP_LIMIT"):
             request["price"] = exchange.price_to_precision(symbol, price)
         postOnly = exchange.safe_value(params, "postOnly", False)
@@ -96,29 +99,28 @@ def create_order_factory(
             request["exec_inst"] = "POST_ONLY"
 
         def subscribe(observer, scheduler=None):
-            ws = socket.value
             recorded_messages = messages.pipe(
                 operators.filter(
-                    lambda x: (
-                        x.result.get("channel") == f'user.order.{market["id"]}'
-                    )
+                    lambda x: (x.result.get("channel") == f'user.order.{market["id"]}')
                 ),
                 operators.replay(),
             )
-            sub = recorded_messages.connect(scheduler=NewThreadScheduler())
+            sub = recorded_messages.connect(scheduler=scheduler)
+            message_id, sender = socket.value.request_to_observable(
+                CryptodotcomRequestMessage(MethodName.CREATE_ORDER, params=request)
+            )
 
             return disposable.CompositeDisposable(
                 sub,
                 messages.pipe(
                     wait_for_response(
-                        ws.send_message(
-                            CryptodotcomRequestMessage(
-                                MethodName.CREATE_ORDER, params=request
-                            )
-                        ),
+                        message_id,
+                        sender,
                         2.0,
                     ),
-                    operators.flat_map(lambda x: just(x.result) if x.code == 0 else throw(x.message)),
+                    operators.flat_map(
+                        lambda x: just(x.result) if x.code == 0 else throw(x.message)
+                    ),
                     operators.flat_map(
                         lambda x: order_confirmation(
                             recorded_messages, exchange, x["order_id"]
